/**
 * This module sets configuration defaults for the AWS infrastructure.
 *
 * Usage:
 *
 *     module "defaults" {
 *       source = "github.com/nuxeo/cloud-aws-stack/defaults"
 *       region = "eu-west-1"
 *       cidr   = "10.0.0.0/16"
 *     }
 *
 */

variable "region" {
  description = "The AWS region"
}

variable "cidr" {
  description = "The CIDR block to provision for the VPC"
}

variable "default_nuxeo_ami" {
  default = {
    us-east-1      = "ami-11111111"
    us-west-1      = "ami-22222222"
    us-west-2      = "ami-33333333"
    eu-west-1      = "ami-44444444"
    eu-central-1   = "ami-55555555"
  }
}

variable "default_binstore_account_ids" {
  default = {
    us-east-1      = "111111111111"
    us-west-2      = "222222222222"
    us-west-1      = "333333333333"
    eu-west-1      = "444444444444"
    eu-central-1   = "555555555555"
  }
}

output "domain_name_servers" {
  value = "${cidrhost(var.cidr, 2)}"
}

output "nuxeo_ami" {
  value = "${lookup(var.default_nuxeo_ami, var.region)}"
}

output "s3_binstore_account_id" {
  value = "${lookup(var.default_binstore_account_ids, var.region)}"
}
